@@ -38,43 +38,44 @@ void KMahjonggLayoutSelector::setupData(KConfigSkeleton * aconfig)
 {
     //Get our currently configured Layout entry
     KConfig * config = aconfig->config();
-    KConfigGroup group = config->group("General");
+    KConfigGroup group = config->group(QStringLiteral("General"));
     QString initialGroup = group.readEntry("Layout_file");
 
-    //The lineEdit widget holds our tileset path, but the user does not manipulate it directly
+    //The lineEdit widget holds our layout path, but the user does not manipulate it directly
     kcfg_Layout->hide();
 
     //No new stuff yet
     getNewButton->hide();
 
-    //Now get our tilesets into a list
-    QStringList tilesAvailable;
+    //Now get our layouts into a list
+    QStringList layoutsAvailable;
 
-    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("layouts/"), QStandardPaths::LocateDirectory);
+    const QStringList dirs = QStandardPaths::locateAll(QStandardPaths::AppDataLocation, QStringLiteral("layouts"), QStandardPaths::LocateDirectory);
     for (const QString & dir : dirs) {
-        const QStringList fileNames = QDir(dir).entryList(QStringList() << QStringLiteral("*.desktop"));
+        const QStringList fileNames = QDir(dir).entryList({QStringLiteral("*.desktop")});
+        layoutsAvailable.reserve(layoutsAvailable.size() + fileNames.size());
         for (const QString & file : fileNames) {
-            tilesAvailable.append(dir + QLatin1Char('/') + file);
+            layoutsAvailable.append(dir + QLatin1Char('/') + file);
         }
     }
-    tilesAvailable.sort();
-    QString namestr(QStringLiteral("Name"));
+    layoutsAvailable.sort();
+
     int numvalidentries = 0;
-    for (int i = 0; i < tilesAvailable.size(); ++i) {
-        KMahjonggLayout * aset = new KMahjonggLayout();
-        QString atileset = tilesAvailable.at(i);
-        if (aset->load(atileset)) {
-            layoutMap.insert(aset->authorProperty(namestr), aset);
-            layoutList->addItem(aset->authorProperty(namestr));
-            //Find if this is our currently configured Tileset
-            if (atileset == initialGroup) {
+    for (const QString &layoutPath : std::as_const(layoutsAvailable)) {
+        auto *alayout = new KMahjonggLayout();
+        if (alayout->load(layoutPath)) {
+            const QString name = alayout->name();
+            layoutMap.insert(name, alayout);
+            layoutList->addItem(name);
+            //Find if this is our currently configured layout
+            if (layoutPath == initialGroup) {
                 //Select current entry
                 layoutList->setCurrentRow(numvalidentries);
                 layoutChanged();
             }
             ++numvalidentries;
         } else {
-            delete aset;
+            delete alayout;
         }
     }
 
@@ -93,9 +94,9 @@ void KMahjonggLayoutSelector::layoutChanged()
     }
 
     kcfg_Layout->setText(selLayout->path());
-    layoutAuthor->setText(selLayout->authorProperty(QStringLiteral("Author")));
-    layoutContact->setText(selLayout->authorProperty(QStringLiteral("AuthorEmail")));
-    layoutDescription->setText(selLayout->authorProperty(QStringLiteral("Description")));
+    layoutAuthor->setText(selLayout->authorName());
+    layoutContact->setText(selLayout->authorEmailAddress());
+    layoutDescription->setText(selLayout->description());
 
     //If settings for tiles/background have been applied, update our preview
     if (m_gameView->getTilesetPath() != Prefs::tileSet()) {
